==> 2.5.zip: piwigo/language/lt_LT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Jei reikės pagalbos - drąsiai kreipkitės konsultacijų mūsų forumuose: %s';
$lang['Installation'] = 'Diegimas';
$lang['Congratulations, Piwigo installation is completed'] = 'Sveikiname, Piwigo diegimas baigtas';
$lang['enter a login for webmaster'] = 'įveskite webmasterio vartotojo vardą';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasterio vartotojo vardas negali turėti simbolių \' ar "';
$lang['Start Install'] = 'Pradėti įdiegimą';
$lang['Try to configure PHP 5'] = 'Pabandyti sukonfigūruoti PHP 5';
$lang['Welcome to your new installation of Piwigo!'] = 'Prašom užeiti į naują Piwigo svetainę!';
$lang['also given by your host provider'] = 'taip pat teikiamas Jūsų hostingo paslaugų tiekėjo';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatyvus būdas - tai nukopijuoti tekstą iš lauko aukščiau ir įrašyti jį į "local/config/database.inc.php" failą. Dėmesio! database.inc.php turi būti įrašyta tik tai, kas yra textarea laukelyje, jokių tuščių eilučių ir tarpų.';
$lang['user login given by your host provider'] = 'login, kurį davė jūsų paslaugų tiekėjas';
$lang['user password given by your host provider'] = 'slaptažodis, kurį davė jūsų paslaugų tiekėjas';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Lankytojai šiuo el-pašto adresu galės susisiekti su administratorium';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Jūs turėtumėte kreiptis pagalbos į savo paslaugų tiekėją, kaip perjungti į PHP 5 pačiam.';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'šį prefiksą turės duomenų bazės lentelės (tai padeda geriau valdyti lenteles)';
$lang['please enter your password again'] = 'dar sykį įveskite savo slaptažodį';
$lang['verification'] = 'patikrinimas';
$lang['Hope to see you back soon.'] = 'Iki greito pasimatymo.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Reikia pagalbos ? Užduokite klausimą <a href="%s">Piwigo pranešimų lentoje</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Dėmesio, jūs galite pakeisti savo konfigūraciją pats ir tada perkrauti Piwigo.';
$lang['PHP 5 is required'] = 'reikalingas PHP 5';
$lang['Password ']['confirm'] = 'Slaptažodis [pakartoti]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo gali pamėginti perjungti Jūsų konfigūraciją į PHP5 sukuriant, ar modifikuojant, .htaccess failą.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo negalėjo sukonfigūruoti PHP 5';
$lang['Sorry!'] = 'Apgailestaujame!';
$lang['User'] = 'Vartotojas';
$lang['Welcome to my photo gallery'] = 'Sveiki atvykę į mano foto galeriją';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jūs galite atsisiųsti konfigūracinį failą ir padėti jį į local/config katalogą, prie Jūsų instaliacijos.';
$lang['Admin configuration'] = 'Administracijos konfigūracija';
$lang['Basic configuration'] = 'Pradinė konfigūracija';
$lang['Can\'t connect to server'] = 'Neišeina prisijungti prie serverio';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Prie serverio prisijungti pavyko, tačiau prie duomenų bazės ne.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Nepavyko sukurti local/config/database.inc.php konfigūracinio failo.';
$lang['Database configuration'] = 'Duomenų bazės konfigūracija';
$lang['Database name'] = 'Duomenų bazės pavadinimas';
$lang['Database table prefix'] = 'Duomenų bazės lentelių prefiksas';
$lang['Default gallery language'] = 'Numatytoji galerijos kalba';
$lang['Download the config file'] = 'Atsisiųsti konfigūracini failą';
$lang['Host'] = 'Hostas';
$lang['It appears your webhost is currently running PHP %s.'] = 'Jūsų webhost\'as naudoja PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Tai bus rodoma lankytojams. Tai būtina puslapio administracijai';
$lang['Just another Piwigo gallery'] = 'Tiesiog dar viena Piwigo galerija';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Saugokite tai slaptai, nes tai leidžia prisijungti prie administratoriaus valdymo skydo.';
$lang['localhost or other, supplied by your host provider'] = 'localhost arba kitas, suteiktas jūsų paslaugų tiekėjo';
?>

==> 14.5.0.zip: piwigo/language/lt_LT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Jei reikės pagalbos - drąsiai kreipkitės konsultacijų mūsų forumuose: %s';
$lang['Installation'] = 'Diegimas';
$lang['Congratulations, Piwigo installation is completed'] = 'Sveikiname, Piwigo diegimas baigtas';
$lang['enter a login for webmaster'] = 'įveskite webmasterio vartotojo vardą';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasterio vartotojo vardas negali turėti simbolių \' ar "';
$lang['Start Install'] = 'Pradėti įdiegimą';
$lang['Try to configure PHP 5'] = 'Pabandyti sukonfigūruoti PHP 5.2';
$lang['Welcome to your new installation of Piwigo!'] = 'Prašom užeiti į naują Piwigo svetainę!';
$lang['also given by your host provider'] = 'taip pat teikiamas Jūsų hostingo paslaugų tiekėjo';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatyvus būdas - tai nukopijuoti tekstą iš lauko aukščiau ir įrašyti jį į "local/config/database.inc.php" failą. Dėmesio! database.inc.php turi būti įrašyta tik tai, kas yra textarea laukelyje, jokių tuščių eilučių ir tarpų.';
$lang['user login given by your host provider'] = 'login, kurį davė jūsų paslaugų tiekėjas';
$lang['user password given by your host provider'] = 'slaptažodis, kurį davė jūsų paslaugų tiekėjas';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Lankytojai šiuo el-pašto adresu galės susisiekti su administratorium';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Jūs turėtumėte kreiptis pagalbos į savo paslaugų tiekėją, kaip perjungti į PHP 5.2 pačiam.';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'šį prefiksą turės duomenų bazės lentelės (tai padeda geriau valdyti lenteles)';
$lang['please enter your password again'] = 'dar sykį įveskite savo slaptažodį';
$lang['verification'] = 'patikrinimas';
$lang['Hope to see you back soon.'] = 'Iki greito pasimatymo.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Reikia pagalbos ? Užduokite klausimą <a href="%s">Piwigo pranešimų lentoje</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Dėmesio, jūs galite pakeisti savo konfigūraciją pats ir tada perkrauti Piwigo.';
$lang['PHP 5 is required'] = 'reikalingas PHP 5.2';
$lang['Password ']['confirm'] = 'Slaptažodis [pakartoti]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo gali pamėginti perjungti Jūsų konfigūraciją į PHP5.2 sukuriant, ar modifikuojant, .htaccess failą.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo negalėjo sukonfigūruoti PHP 5.2';
$lang['Sorry!'] = 'Apgailestaujame!';
$lang['User'] = 'Vartotojas';
$lang['Welcome to my photo gallery'] = 'Sveiki atvykę į mano foto galeriją';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jūs galite atsisiųsti konfigūracinį failą ir padėti jį į local/config katalogą, prie Jūsų instaliacijos.';
$lang['Admin configuration'] = 'Administracijos konfigūracija';
$lang['Basic configuration'] = 'Pradinė konfigūracija';
$lang['Can\'t connect to server'] = 'Neišeina prisijungti prie serverio';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Prie serverio prisijungti pavyko, tačiau prie duomenų bazės ne.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Nepavyko sukurti local/config/database.inc.php konfigūracinio failo.';
$lang['Database configuration'] = 'Duomenų bazės konfigūracija';
$lang['Database name'] = 'Duomenų bazės pavadinimas';
$lang['Database table prefix'] = 'Duomenų bazės lentelių prefiksas';
$lang['Default gallery language'] = 'Numatytoji galerijos kalba';
$lang['Download the config file'] = 'Atsisiųsti konfigūracini failą';
$lang['Host'] = 'Hostas';
$lang['It appears your webhost is currently running PHP %s.'] = 'Jūsų webhost\'as naudoja PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Tai bus rodoma lankytojams. Tai būtina puslapio administracijai';
$lang['Just another Piwigo gallery'] = 'Tiesiog dar viena Piwigo galerija';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Saugokite tai slaptai, nes tai leidžia prisijungti prie administratoriaus valdymo skydo.';
$lang['localhost or other, supplied by your host provider'] = 'localhost arba kitas, suteiktas jūsų paslaugų tiekėjo';
